greenheart.tools.eco.hopp\_mgmt
===============================

.. automodule:: greenheart.tools.eco.hopp_mgmt

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      run_hopp
      setup_hopp
   
   

   
   
   

   
   
   



